This crate contains kube-rs compatible bindings for Kubernetes custom resources for the resources.teleport.dev group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
resources.teleport.dev/v1
TeleportLoginRuleTeleportOktaImportRule
resources.teleport.dev/v2
TeleportProvisionTokenTeleportSAMLConnectorTeleportUser
resources.teleport.dev/v3
TeleportGithubConnectorTeleportOIDCConnector
resources.teleport.dev/v5
TeleportRole
resources.teleport.dev/v6
TeleportRole